<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>EllipseCPP</name>
    <message>
        <source>&amp;Full Ellipse</source>
        <translation type="vanished">&amp;F 楕円弧</translation>
    </message>
    <message>
        <source>&amp;Full Ellipse with Center, Point, Ratio</source>
        <translation type="vanished">&amp;F 楕円弧</translation>
    </message>
    <message>
        <location filename="../EllipseCPPInit.js" line="+2"/>
        <source>&amp;Ellipse (Center, Point, Ratio)</source>
        <translation>楕円（中心,点,比率）</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw full ellipse from center, major point and ratio</source>
        <translation>中心、長軸点と比率から楕円を描画</translation>
    </message>
</context>
</TS>
